require "import"
import "android.widget.*"
import "android.view.*"
import "android.net.Uri"
import "android.content.Intent"
import "android.content.Context"
import "android.content.ClipData"
import "android.content.ClipboardManager"
import "java.io.BufferedReader"
import "java.io.FileReader"

-- UI Layout
local layout = {
  ScrollView,
  {
    LinearLayout,
    orientation = "vertical",
    padding = "16dp",
    gravity = "center",
    {
      TextView,
      id = "welcomeText",
      text = "CPU Checker",
      textSize = "20sp",
      gravity = "center",
      layout_width = "match_parent",
      layout_height = "wrap_content"
    },
    {
      TextView,
      text = "Developed by: Sujan Rai",
      textSize = "16sp",
      gravity = "center",
      layout_width = "match_parent",
      layout_height = "wrap_content"
    },
    {
      TextView,
      text = "Join my Telegram channel for more apps and resources",
      textSize = "16sp",
      gravity = "center",
      layout_width = "match_parent",
      layout_height = "wrap_content"
    },
    {
      Button,
      id = "telegramBtn",
      text = "Join Telegram Channel",
      layout_width = "wrap_content",
      layout_height = "wrap_content"
    },
    {
      Button,
      id = "cpuCheckBtn",
      text = "Check CPU Info",
      layout_width = "wrap_content",
      layout_height = "wrap_content"
    },
    {
      TextView,
      id = "cpuTextAdvanced",
      text = "Advanced CPU Info Will Appear Here...",
      textSize = "16sp",
      padding = "10dp",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      background = "#EEEEEE"
    },
    {
      TextView,
      id = "cpuArchText",
      text = "Your CPU architecture is: ",
      textSize = "16sp",
      padding = "10dp",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      background = "#DDFFDD"
    },
    {
      LinearLayout,
      orientation = "horizontal",
      gravity = "center",
      {
        Button,
        id = "copyBtn",
        text = "Copy CPU Info",
        layout_width = "wrap_content",
        layout_height = "wrap_content"
      },
      {
        Button,
        id = "exitBtn",
        text = "Exit",
        layout_width = "wrap_content",
        layout_height = "wrap_content"
      }
    }
  }
}

activity.setContentView(loadlayout(layout))

-- Telegram button
telegramBtn.onClick = function()
  local url = "https://t.me/techvisionarynepal"
  local intent = Intent(Intent.ACTION_VIEW)
  intent.setData(Uri.parse(url))
  activity.startActivity(intent)
end

-- Exit button
exitBtn.onClick = function()
  activity.finish()
end

-- Copy CPU info
copyBtn.onClick = function()
  local clipboard = activity.getSystemService(Context.CLIPBOARD_SERVICE)
  local clip = ClipData.newPlainText("cpuText", cpuTextAdvanced.getText())
  clipboard.setPrimaryClip(clip)
  Toast.makeText(activity, "CPU info copied to clipboard", Toast.LENGTH_SHORT).show()
end

-- Parse and display CPU info in readable format
function getCpuInfo()
  local result = ""
  local arch = "Unknown"
  local infoTable = {}

  pcall(function()
    local reader = BufferedReader(FileReader("/proc/cpuinfo"))
    local line
    while true do
      line = reader.readLine()
      if line == nil then break end
      local key, value = line:match("([^:]+)%s*:%s*(.+)")
      if key and value then
        infoTable[key:lower()] = value
      end
    end
    reader.close()
  end)

  if next(infoTable) == nil then
    cpuTextAdvanced.setText("Unable to retrieve CPU info.")
    cpuArchText.setText("Your CPU architecture is: Unknown")
  else
    local model = infoTable["model name"] or infoTable["Processor"] or "Unknown"
    local cores = infoTable["cpu cores"] or "N/A"
    local hardware = infoTable["hardware"] or "N/A"
    arch = infoTable["architecture"] or infoTable["cpu architecture"] or "Unknown"

    result = string.format(
      "CPU Model: %s\nCPU Cores: %s\nHardware: %s\nArchitecture: %s",
      model, cores, hardware, arch
    )

    cpuTextAdvanced.setText(result)
    cpuArchText.setText("Your CPU architecture is: " .. arch)
  end
end

-- CPU Check button
cpuCheckBtn.onClick = function()
  getCpuInfo()
end